@@ -152,14 +152,9 @@ namespace
       // don't look at binaries
       && leaf != "bin"
       && leaf != "bin.v2"
-      // this really out of our hands
-      && leaf != "jam_src"
-      && local.find("tools/jam/src") != 0
-      && local.find("tools/build/v2/engine") != 0
-      // too many issues with generated HTML files
-      && leaf != "status"
       // no point in checking doxygen xml output
       && local.find("doc/xml") != 0
+      && local.find("doc\\xml") != 0
       // ignore some web files
       && leaf != ".htaccess"
       // ignore svn files:
@@ -169,6 +164,8 @@ namespace
       && leaf != ".bzr"
       // ignore OS X directory info files:
       && leaf != ".DS_Store"
+      // ignore if tag file present
+      && !boost::filesystem::exists(pth / "boost-no-inspect")
       ;
   }
 
@@ -348,6 +345,32 @@ namespace
       std::cout << "</blockquote>\n"; 
   }
 
+//  html_encode  -------------------------------------------------------------//
+
+  std::string html_encode(std::string const& text)
+  {
+    std::string result;
+    
+    for(std::string::const_iterator it = text.begin(),
+        end = text.end(); it != end; ++it)
+    {
+      switch(*it) {
+      case '<':
+        result += "&lt;";
+        break;
+      case '>':
+        result += "&gt;";
+        break;
+      case '&':
+        result += "&amp;";
+        break;
+      default:
+        result += *it;
+      }      
+    }
+    
+    return result;
+  }
 
 //  display_details  ---------------------------------------------------------//
 
@@ -442,8 +465,8 @@ namespace
 
           // print the message
           if (itr->line_number)
-            std::cout << sep << "(line " << itr->line_number << ") " << itr->msg;
-          else std::cout << sep << itr->msg;
+            std::cout << sep << "(line " << itr->line_number << ") " << html_encode(itr->msg);
+          else std::cout << sep << html_encode(itr->msg);
 
           first_sep = false;
         }
